import Lib
main = configCheckMain "main"
